==> bigloo_2.7a-1.tar.gz: bigloo2.7a/runtime/Eval/everror.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Eval/everror.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Apr 14 13:46:57 2004                          */
;*    Last change :  Thu Oct  6 10:27:41 2005 (serrano)                */
;*    Copyright   :  2004-05 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The error of evmeaning                                           */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __everror

   (include "Eval/byte-code.sch")
   
   (import  __type
 	    __object
	    __error
	    __bigloo
	    __tvector
	    __structure
	    __tvector
	    __bexit
	    __os
	    __bit
	    __param
	    
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_equivalence_6_2
	    __r4_booleans_6_1
	    __r4_symbols_6_4
	    __r4_strings_6_7
	    __r4_pairs_and_lists_6_3
	    __r4_input_6_10_2
	    __r4_control_features_6_9
	    __r4_vectors_6_8
	    __r4_ports_6_10_1
	    __r4_output_6_10_3)
	    
   (export *current-bcode*
	   (evmeaning-error ::obj ::obj ::obj ::obj)
	   (evmeaning-reset-error!)
	   (evmeaning-warning ::obj . ::obj)
	   (evmeaning-notify-error ::obj ::obj ::obj)
	   (evmeaning-notify-exception e)
	   (evmeaning-exception-handler ::obj)
	   (evmeaning-arity-error ::obj ::obj)))

;*---------------------------------------------------------------------*/
;*    *current-bcode* ...                                              */
;*---------------------------------------------------------------------*/
(define *current-bcode* #f)

;*---------------------------------------------------------------------*/
;*    evmeaning-reset-error! ...                                       */
;*---------------------------------------------------------------------*/
(define (evmeaning-reset-error!)
   (set! *current-bcode* #f))
   
;*---------------------------------------------------------------------*/
;*    evmeaning-error ...                                              */
;*---------------------------------------------------------------------*/
(define (evmeaning-error bcode proc mes obj)
   (if (evcode? bcode)
       (match-case (evcode-loc bcode)
	  ((at ?fname ?loc)
	   (error/location proc mes obj fname loc))
	  (else
	   (error proc mes obj)))
       (error proc mes obj)))

;*---------------------------------------------------------------------*/
;*    evmeaning-warning ...                                            */
;*---------------------------------------------------------------------*/
(define (evmeaning-warning bcode . args)
   (if (evcode? bcode)
       (match-case (evcode-loc bcode)
	  ((at ?fname ?loc)
	   (raise (make-&eval-warning fname loc args)))
	  (else
	   (raise (make-&eval-warning #f #f args))))
       (raise (make-&eval-warning #f #f args))))

;*---------------------------------------------------------------------*/
;*    evmeaning-notify-error ...                                       */
;*---------------------------------------------------------------------*/
(define (evmeaning-notify-error proc mes obj)
   (bind-exit (escape)
      (with-exception-handler
       (lambda (e)
	  (error-notify e)
	  (escape #unspecified))
       (lambda ()
	  (cond
	     ((epair? obj)
	      (match-case (cer obj)
		 ((at ?fname ?loc)
		  (error/location proc mes obj fname loc))
		 (else
		  (error proc mes obj))))
	     ((evcode? *current-bcode*)
	      (match-case (evcode-loc *current-bcode*)
		 ((at ?fname ?loc)
		  (set! *current-bcode* #f)
		  (error/location proc mes obj fname loc))
		 (else
		  (error proc mes obj))))
	     (else
	      (error proc mes obj)))))))

;*---------------------------------------------------------------------*/
;*    evmeaning-notify-exception ...                                   */
;*---------------------------------------------------------------------*/
(define (evmeaning-notify-exception e)
   (when (&error? e)
      (if (evcode? *current-bcode*)
	  (match-case (evcode-loc *current-bcode*)
	     ((at ?fname ?loc)
	      (set! *current-bcode* #f)
	      (error-notify (duplicate::&error e
			       (fname fname)
			       (location loc))))
	     (else
	      (error-notify e)))
	  (error-notify e))))
   
;*---------------------------------------------------------------------*/
;*    evmeaning-exception-handler ...                                  */
;*---------------------------------------------------------------------*/
(define (evmeaning-exception-handler e)
   (if (&error? e)
       (if (evcode? *current-bcode*)
	   (match-case (evcode-loc *current-bcode*)
	      ((at ?fname ?loc)
	       (set! *current-bcode* #f)
	       (raise (duplicate::&error e
			 (fname fname)
			 (location loc))))
	      (else
	       (raise e)))
	   (raise e))
       (raise e)))
   
;*---------------------------------------------------------------------*/
;*    evmeaning-arity-error ...                                        */
;*---------------------------------------------------------------------*/
(define (evmeaning-arity-error code name)
   (evmeaning-error code 'eval "Incorrect number of arguments" name))

==> bigloo2.9a.tar.gz: bigloo2.9a/runtime/Eval/everror.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/runtime/Eval/everror.scm             */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Apr 14 13:46:57 2004                          */
;*    Last change :  Wed Dec  6 15:15:19 2006 (serrano)                */
;*    Copyright   :  2004-06 Manuel Serrano                            */
;*    -------------------------------------------------------------    */
;*    The error of evmeaning                                           */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    The module                                                       */
;*---------------------------------------------------------------------*/
(module __everror
   
   (include "Eval/byte-code.sch")
   
   (import  __type
 	    __object
	    __error
	    __bigloo
	    __tvector
	    __structure
	    __tvector
	    __bexit
	    __os
	    __bit
	    __param
	    
	    __r4_numbers_6_5
	    __r4_numbers_6_5_fixnum
	    __r4_numbers_6_5_flonum
	    __r4_characters_6_6
	    __r4_equivalence_6_2
	    __r4_booleans_6_1
	    __r4_symbols_6_4
	    __r4_strings_6_7
	    __r4_pairs_and_lists_6_3
	    __r4_input_6_10_2
	    __r4_control_features_6_9
	    __r4_vectors_6_8
	    __r4_ports_6_10_1
	    __r4_output_6_10_3)
   
   (extern (macro $evmeaning-byte-code::obj ()
		  "BGL_BYTECODE")
	   (macro $evmeaning-byte-code-set!::obj (::obj)
		  "BGL_BYTECODE_SET"))
   
   (java   (class foreign
	      (method static $evmeaning-byte-code::obj ()
		      "BGL_BYTECODE")
	      (method static $evmeaning-byte-code-set!::obj (::obj)
		      "BGL_BYTECODE_SET")))
   
   (export (evmeaning-error ::obj ::obj ::obj ::obj)
	   (evmeaning-type-error ::obj ::obj ::obj ::obj)
	   (evmeaning-reset-error!)
	   (evmeaning-warning ::obj . ::obj)
	   (evmeaning-annotate-exception! ::obj)
	   (evmeaning-exception-handler ::obj)
	   (evmeaning-arity-error ::obj ::obj)))

;*---------------------------------------------------------------------*/
;*    evmeaning-reset-error! ...                                       */
;*---------------------------------------------------------------------*/
(define (evmeaning-reset-error!)
   ($evmeaning-byte-code-set! #f))
   
;*---------------------------------------------------------------------*/
;*    evmeaning-error ...                                              */
;*---------------------------------------------------------------------*/
(define (evmeaning-error bcode proc mes obj)
   (if (evcode? bcode)
       (match-case (evcode-loc bcode)
	  ((at ?fname ?loc)
	   (error/location proc mes obj fname loc))
	  (else
	   (error proc mes obj)))
       (error proc mes obj)))

;*---------------------------------------------------------------------*/
;*    evmeaning-type-error ...                                         */
;*---------------------------------------------------------------------*/
(define (evmeaning-type-error bcode proc mes obj)
   (if (evcode? bcode)
       (match-case (evcode-loc bcode)
	  ((at ?fname ?loc)
	   (bigloo-type-error/location proc mes obj fname loc))
	  (else
	   (bigloo-type-error proc mes obj)))
       (bigloo-type-error proc mes obj)))

   
;*---------------------------------------------------------------------*/
;*    evmeaning-warning ...                                            */
;*---------------------------------------------------------------------*/
(define (evmeaning-warning bcode . args)
   (if (evcode? bcode)
       (match-case (evcode-loc bcode)
	  ((at ?fname ?loc)
	   (warning-notify (make-&eval-warning fname loc args)))
	  (else
	   (warning-notify (make-&eval-warning #f #f args))))
       (warning-notify (make-&eval-warning #f #f args))))

;*---------------------------------------------------------------------*/
;*    evmeaning-annotate-exception! ...                                */
;*---------------------------------------------------------------------*/
(define (evmeaning-annotate-exception! e)
   (if (and (&exception? e)
	    (not (&exception-fname e))
	    (evcode? ($evmeaning-byte-code)))
       (match-case (evcode-loc ($evmeaning-byte-code))
	  ((at ?fname ?loc)
	   (&exception-fname-set! e fname)
	   (&exception-location-set! e loc)
	   e)
	  (else
	   e))
       e))
   
;*---------------------------------------------------------------------*/
;*    evmeaning-exception-handler ...                                  */
;*    -------------------------------------------------------------    */
;*    This handler is just in charge of adding a location to           */
;*    the error/warning.                                               */
;*---------------------------------------------------------------------*/
(define (evmeaning-exception-handler e)
   (raise (evmeaning-annotate-exception! e)))

;*---------------------------------------------------------------------*/
;*    evmeaning-arity-error ...                                        */
;*---------------------------------------------------------------------*/
(define (evmeaning-arity-error code name)
   (evmeaning-error code 'eval "Incorrect number of arguments" name))
